@@ -134,7 +134,7 @@ static void* do_aio( void *varg )
 		retval = my_ibrd( conf, conf->async.buffer, conf->async.buffer_length, &count);
 		break;
 	case GPIB_AIO_WRITE:
-		count = retval = my_ibwrt( conf, conf->async.buffer, conf->async.buffer_length );
+		retval = my_ibwrt(conf, conf->async.buffer, conf->async.buffer_length, &count);
 		break;
 	default:
 		retval = -1;
@@ -145,7 +145,10 @@ static void* do_aio( void *varg )
 	pthread_mutex_lock( &conf->async.lock );
 	if(retval < 0)
 	{
-		conf->async.ibcntl = ThreadIbcntl();
+		if(ThreadIberr() != EDVR)
+			conf->async.ibcntl = count;
+		else
+			conf->async.ibcntl = ThreadIbcntl();
 		conf->async.iberr = ThreadIberr();
 		conf->async.ibsta = CMPL | ERR;
 	}else
